You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@maven.apache.org by br...@apache.org on 2007/07/08 03:16:29 UTC

svn commit: r554288 - in /maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src: main/java/org/apache/maven/plugin/eclipse/ main/java/org/apache/maven/plugin/ide/ site/apt/examples/ site/fml/ test/java/org/apache/maven/plugin/eclipse/

Author: brianf
Date: Sat Jul  7 18:16:28 2007
New Revision: 554288

URL: http://svn.apache.org/viewvc?view=rev&rev=554288
Log:
added docs for MECLIPSE-292

Modified:
    maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/main/java/org/apache/maven/plugin/eclipse/EclipsePlugin.java
    maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/main/java/org/apache/maven/plugin/ide/AbstractIdeSupportMojo.java
    maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/site/apt/examples/attach-library-sources.apt
    maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/site/fml/faq.fml
    maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/test/java/org/apache/maven/plugin/eclipse/EclipsePluginTest.java

Modified: maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/main/java/org/apache/maven/plugin/eclipse/EclipsePlugin.java
URL: http://svn.apache.org/viewvc/maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/main/java/org/apache/maven/plugin/eclipse/EclipsePlugin.java?view=diff&rev=554288&r1=554287&r2=554288
==============================================================================
--- maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/main/java/org/apache/maven/plugin/eclipse/EclipsePlugin.java (original)
+++ maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/main/java/org/apache/maven/plugin/eclipse/EclipsePlugin.java Sat Jul  7 18:16:28 2007
@@ -226,7 +226,7 @@
     private List classpathContainers;
 
     /**
-     * Enables/disables the downloading of source attachments. Defaults to false.
+     * Enables/disables the downloading of source attachments. Defaults to false. DEPRECATED - use downloadSources
      *
      * @parameter expression="${eclipse.downloadSources}"
      * @deprecated use downloadSources

Modified: maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/main/java/org/apache/maven/plugin/ide/AbstractIdeSupportMojo.java
URL: http://svn.apache.org/viewvc/maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/main/java/org/apache/maven/plugin/ide/AbstractIdeSupportMojo.java?view=diff&rev=554288&r1=554287&r2=554288
==============================================================================
--- maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/site/apt/examples/attach-library-sources.apt (original)
+++ maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/site/apt/examples/attach-library-sources.apt Sat Jul  7 18:16:28 2007
@@ -3,20 +3,20 @@
  ------
  Edwin Punzalan
  ------
- 14 July 2006
+ 7 July 2007
  ------
 
 
-Attach Library Sources
+Attach Library Sources and Javadocs
 
   Artifacts with sources deployed can be attached to Eclipse libraries using
-  <<<downloadSources>>>.  The sources of the libraries <must> exist in the
+  <<<downloadSources>>>. Javadocs may be attached using <<<downloadJavadocs>>> The sources and javadocs of the libraries <must> exist in the
   repository so that the plugin can download it and attach it.
 
   The following example shows how to do this in the command-line:
 
 +-----
-mvn eclipse:eclipse -DdownloadSources=true
+mvn eclipse:eclipse -DdownloadSources=true  -DdownloadJavadocs=true
 +-----
 
   or in your pom.xml:
@@ -33,6 +33,7 @@
         <artifactId>maven-eclipse-plugin</artifactId>
         <configuration>
           <downloadSources>true</downloadSources>
+          <downloadJavadocs>true</downloadJavadocs>
         </configuration>
       </plugin>
       [...]

Modified: maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/site/fml/faq.fml
URL: http://svn.apache.org/viewvc/maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/site/fml/faq.fml?view=diff&rev=554288&r1=554287&r2=554288
==============================================================================
--- maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/site/fml/faq.fml (original)
+++ maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/site/fml/faq.fml Sat Jul  7 18:16:28 2007
@@ -20,25 +20,9 @@
      </answer>
    </faq>
    <faq id="import-javadoc">
-     <question>Can I make the Eclipse plugin to download and to attach javadocs to my libraries?</question>
+     <question>Can I make the Eclipse plugin download and attach javadocs to my libraries?</question>
      <answer>
-       <p>Quoting what Fabrizio said in the mailing list...</p>
-       <i>
-       <p>"The current revision in svn of the Eclipse plugin (which is expected
-       to be released as soon as an usable wtp 1.0.1 build will be out) has
-       support for javadoc attachments, as an alternative to source jars."</p>
-
-       <p>"When using the downloadSources flag if a source jar is not found the
-       plugin will look for a javadoc jar. This is expecially useful for non
-       open source projects and when used with Eclipse 3.2 (in Eclipse 3.2 M4
-       javadoc view and editor tooltips also work with javadoc archives)."</p>
-
-       <p>"I didn't find useful to have both sources and javadocs attached, since
-       javadocs are automatically extracted by Eclipse: if you think this
-       should be needed please post an enhancement request in Jira with the
-       reasons... "</p>
-       </i>
-       <p>To go the the mailing list thread of this topic, click <a href="http://www.nabble.com/forum/ViewPost.jtp?post=2370602&amp;framed=y">here</a></p>
+      <p>As of version 2.4, there is a new flag, downloadJavadocs that behaves exactly like downloadSources except for javadocs. See more information here: <a href="examples/attach-library-sources.html">Attach Library Sources</a>. </p>
      </answer>
    </faq>
  </part>

Modified: maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/test/java/org/apache/maven/plugin/eclipse/EclipsePluginTest.java
URL: http://svn.apache.org/viewvc/maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/test/java/org/apache/maven/plugin/eclipse/EclipsePluginTest.java?view=diff&rev=554288&r1=554287&r2=554288
==============================================================================
--- maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/test/java/org/apache/maven/plugin/eclipse/EclipsePluginTest.java (original)
+++ maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/test/java/org/apache/maven/plugin/eclipse/EclipsePluginTest.java Sat Jul  7 18:16:28 2007
@@ -358,4 +358,12 @@
     {
             testProject( "project-33" );
     }*/
+    
+    
+    /*TODO: Add a test for downloadJavadocs. Currently, eclipse doesn't support having variables in the javadoc
+     * path. This means that the expected .classpath can't match the final result as the result will
+     * have the absolute path to the user's local repo.
+     */
+    
+    
 }
--- maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/main/java/org/apache/maven/plugin/ide/AbstractIdeSupportMojo.java (original)
+++ maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/main/java/org/apache/maven/plugin/ide/AbstractIdeSupportMojo.java Sat Jul  7 18:16:28 2007
@@ -192,9 +192,9 @@
      * <code>mvn-eclipse-cache.properties</code> in order
      * to reset this cache.
      * 
-     * @parameter expression="${downloadJavadoc}"
+     * @parameter expression="${downloadJavadocs}"
      */
-    protected boolean downloadJavadoc;
+    protected boolean downloadJavadocs;
 
     /**
      * Plexus logger needed for debugging manual artifact resolution.
@@ -346,23 +346,23 @@
     }
 
     /**
-     * Getter for <code>downloadJavadoc</code>.
+     * Getter for <code>downloadJavadocs</code>.
      * 
-     * @return Returns the downloadJavadoc.
+     * @return Returns the downloadJavadocs.
      */
-    public boolean getDownloadJavadoc()
+    public boolean getDownloadJavadocs()
     {
-        return this.downloadJavadoc;
+        return this.downloadJavadocs;
     }
 
     /**
-     * Setter for <code>downloadJavadoc</code>.
+     * Setter for <code>downloadJavadocs</code>.
      * 
      * @param downloadJavadoc The downloadJavadoc to set.
      */
-    public void setDownloadJavadoc( boolean downloadJavadoc )
+    public void setDownloadJavadocs( boolean downloadJavadoc )
     {
-        this.downloadJavadoc = downloadJavadoc;
+        this.downloadJavadocs = downloadJavadoc;
     }
     
     /**
@@ -867,7 +867,7 @@
                                                                        unavailableArtifactsCache );
         missingSourceDependencies.addAll( missingSources );
 
-        final List missingJavadocs = resolveDependenciesWithClassifier( deps, "javadoc", getDownloadJavadoc(),
+        final List missingJavadocs = resolveDependenciesWithClassifier( deps, "javadoc", getDownloadJavadocs(),
                                                                         unavailableArtifactsCache );
         missingJavadocDependencies.addAll( missingJavadocs );
 
@@ -1000,7 +1000,7 @@
 
         if ( !missingJavadocDependencies.isEmpty() )
         {
-            if ( getDownloadJavadoc() )
+            if ( getDownloadJavadocs() )
             {
                 msg.append( Messages.getString( "javadocnotavailable" ) ); //$NON-NLS-1$
             }
@@ -346,23 +346,23 @@
      * 
-     * @param downloadJavadoc The downloadJavadoc to set.
+     * @param downloadJavadocs The downloadJavadocs to set.
      */

Modified: maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/site/apt/examples/attach-library-sources.apt
URL: http://svn.apache.org/viewvc/maven/plugins/branches/maven-eclipse-plugin-MECLIPSE-292/src/site/apt/examples/attach-library-sources.apt?view=diff&rev=554288&r1=554287&r2=554288
==============================================================================